[![Python 3](https://img.shields.io/pypi/v/QLog)](https://pypi.org/project/QLog/)
[![Python 3](https://img.shields.io/pypi/pyversions/QLog)](https://pypi.org/project/QLog/)
[![Python 3](https://img.shields.io/pypi/l/QLog)](https://pypi.org/project/QLog/)

![Test](https://github.com/QuantumApplications/QLog-Python/workflows/Test/badge.svg)
[![codecov](https://codecov.io/gh/QuantumApplications/QLog/branch/master/graph/badge.svg)](https://codecov.io/gh/QuantumApplications/QLog-Python)
[![BCH compliance](https://bettercodehub.com/edge/badge/QuantumApplications/QLog-Python?branch=master)](https://bettercodehub.com/)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/74d8cf67a7d94434a6528da5f9d30882)](https://www.codacy.com/gh/QuantumApplications/QLog-Python/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=QuantumApplications/QLog-Python&amp;utm_campaign=Badge_Grade)
[![codebeat badge](https://codebeat.co/badges/0d6fcdba-ab00-46c1-9092-84a463ed6f02)](https://codebeat.co/projects/github-com-quantumapplications-qlog-python-master)
